@@ -14,6 +14,7 @@ CREATE TABLE workflow_history (
   state             varchar(30) not null,
   workflow_user     varchar(50) null,
   history_date      timestamp,
-  primary key( workflow_hist_id )
+  primary key( workflow_hist_id ),
+  foreign key( workflow_id ) references workflow( workflow_id )
 );
 
